@@ -9,6 +9,7 @@ import re
 import base64
 import argparse
 import importlib
+from typing import Dict
 
 import pydwf
 from pydwf import DwfLibrary, DwfEnumConfigInfo
@@ -85,7 +86,7 @@ def list_devices(use_obsolete_api: bool, list_configurations: bool, full_tooltip
 
             num_config = dwf.deviceEnum.enumerateConfigurations(device_index)
 
-            string_lookup_table: dict[str, str] = {}
+            string_lookup_table: Dict[str, str] = {}
 
             for configuration_parameter in DwfEnumConfigInfo:
 
