@@ -2,6 +2,8 @@
 
 # pylint: disable=too-many-lines
 
+from typing import Tuple, List
+
 import numpy as np
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -26,11 +28,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
 
     # pylint: disable=too-many-public-methods
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               INSTRUMENT CONTROL                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                               INSTRUMENT CONTROL                                                #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def reset(self) -> None:
         """Reset all |AnalogIn| instrument parameters to default values.
@@ -104,17 +106,17 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         status_ = DwfState(c_status.value)
         return status_
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               STATUS VARIABLES                                                   #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                STATUS VARIABLES                                                 #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def statusTime(self) -> tuple[int, int, int]:
+    def statusTime(self) -> Tuple[int, int, int]:
         """Retrieve the timestamp of the current status information.
 
         Returns:
-            tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
+            Tuple[int, int, int]: A three-element tuple, indicating the POSIX timestamp of the status request.
             The first element is the POSIX second, the second and third element are the numerator and denominator,
             respectively, of the fractional part of the second.
 
@@ -230,7 +232,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         index_write = c_index_write.value
         return index_write
 
-    def statusRecord(self) -> tuple[int, int, int]:
+    def statusRecord(self) -> Tuple[int, int, int]:
         """Retrieve information about the recording process.
 
         Data loss occurs when the device acquisition is faster than the read process to the PC.
@@ -245,7 +247,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         equal to buffer_size / sample_frequency).
 
         Returns:
-            tuple[int, int, int]: A three-element tuple containing the counts for
+            Tuple[int, int, int]: A three-element tuple containing the counts for
             *available*, *lost*, and *corrupt* data samples, in that order.
 
         Raises:
@@ -266,11 +268,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         data_corrupt = c_data_corrupt.value
         return (data_available, data_lost, data_corrupt)
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               STATUS DATA RETRIEVAL                                              #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              STATUS DATA RETRIEVAL                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def statusData(self, channel_index: int, count: int) -> np.ndarray:
         """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
@@ -376,7 +378,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return samples
 
-    def statusNoise(self, channel_index: int, count: int) -> tuple[np.ndarray, np.ndarray]:
+    def statusNoise(self, channel_index: int, count: int) -> Tuple[np.ndarray, np.ndarray]:
         """Retrieve the acquired noise samples from the specified |AnalogIn| instrument channel.
 
         Parameters:
@@ -403,7 +405,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return (noise_min, noise_max)
 
-    def statusNoise2(self, channel_index: int, offset: int, count: int) -> tuple[np.ndarray, np.ndarray]:
+    def statusNoise2(self, channel_index: int, offset: int, count: int) -> Tuple[np.ndarray, np.ndarray]:
         """Retrieve the acquired data samples from the specified |AnalogIn| instrument channel.
 
         Parameters:
@@ -432,11 +434,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             raise self.dwf.exception()
         return (noise_min, noise_max)
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               ACQUISITION CONFIGURATION                                          #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                            ACQUISITION CONFIGURATION                                            #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def bitsInfo(self) -> int:
         """Get the fixed the number of bits used by the |AnalogIn| ADC.
@@ -444,8 +446,9 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         The number of bits can only be queried; it cannot be changed.
 
         Note:
-            The Analog Discovery 2 uses an |Analog Devices AD9648| two-channel ADC. It converts 14-bit samples at a rate
-            of up to 125 MHz. So for the Analog Discovery 2, this method always returns 14.
+            The Analog Discovery 2 uses an |Analog Devices AD9648| two-channel ADC.
+            It converts 14-bit samples at a rate of up to 125 MHz.
+            So for the Analog Discovery 2, this method always returns 14.
 
         Returns:
             int: The number of bits per sample for each of the |AnalogIn| channels.
@@ -501,12 +504,12 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         record_duration = c_record_duration.value
         return record_duration
 
-    def frequencyInfo(self) -> tuple[float, float]:
+    def frequencyInfo(self) -> Tuple[float, float]:
         """Retrieve the minimum and maximum configurable ADC sample frequency of the |AnalogIn| instrument,
         in samples/second.
 
         Returns:
-            tuple[float, float]: The valid sample frequency range (min, max), in samples/second.
+            Tuple[float, float]: The valid sample frequency range (min, max), in samples/second.
 
         Raises:
             DwfLibraryError: An error occurred while getting the allowed sample frequency range.
@@ -552,7 +555,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         sample_frequency = c_sample_frequency.value
         return sample_frequency
 
-    def bufferSizeInfo(self) -> tuple[int, int]:
+    def bufferSizeInfo(self) -> Tuple[int, int]:
         """Returns the minimum and maximum allowable buffer size for the |AnalogIn| instrument, in samples.
 
         When using the :py:attr:`~pydwf.core.auxiliary.enum_types.DwfAcquisitionMode.Record` acquisition mode,
@@ -567,7 +570,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             16384, depending on the device configuration.
 
         Returns:
-            tuple[int, int]: A two-element tuple.
+            Tuple[int, int]: A two-element tuple.
             The first element is the minimum buffer size, the second element is the maximum buffer size.
 
         Raises:
@@ -675,11 +678,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         noise_buffer_size = c_noise_buffer_size.value
         return noise_buffer_size
 
-    def acquisitionModeInfo(self) -> list[DwfAcquisitionMode]:
+    def acquisitionModeInfo(self) -> List[DwfAcquisitionMode]:
         """Get a list of valid |AnalogIn| instrument acquisition modes.
 
         Returns:
-            list[DwfAcquisitionMode]: A list of valid acquisition modes for the |AnalogIn| instrument.
+            List[DwfAcquisitionMode]: A list of valid acquisition modes for the |AnalogIn| instrument.
 
         Raises:
             DwfLibraryError: An error occurred while getting the acquisition mode info.
@@ -723,11 +726,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         acquisition_mode = DwfAcquisitionMode(c_acquisition_mode.value)
         return acquisition_mode
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                    CHANNEL COUNT                                                 #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                                  CHANNEL COUNT                                                  #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def channelCount(self) -> int:
         """Read the number of |AnalogIn| input channels.
@@ -745,11 +748,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_count = c_channel_count.value
         return channel_count
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                                 CHANNEL CONFIGURATION                                            #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                              CHANNEL CONFIGURATION                                              #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def channelEnableSet(self, channel_index: int, channel_enable: bool) -> None:
         """Enable or disable the specified |AnalogIn| input channel.
@@ -784,11 +787,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_enable = bool(c_channel_enable.value)
         return channel_enable
 
-    def channelFilterInfo(self) -> list[DwfAnalogInFilter]:
+    def channelFilterInfo(self) -> List[DwfAnalogInFilter]:
         """Get a list of valid |AnalogIn| channel filter settings.
 
         Returns:
-            list[DwfAnalogInFilter]: A list of valid channel filter settings.
+            List[DwfAnalogInFilter]: A list of valid channel filter settings.
 
         Raises:
             DwfLibraryError: An error occurred while getting the channel filter info.
@@ -835,7 +838,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_filter = DwfAnalogInFilter(c_channel_filter.value)
         return channel_filter
 
-    def channelRangeInfo(self) -> tuple[float, float, int]:
+    def channelRangeInfo(self) -> Tuple[float, float, int]:
         """Report the possible voltage range of the |AnalogIn| input channels, in Volts.
 
         The values returned represent ideal values.
@@ -846,7 +849,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             in a different representation.
 
         Returns:
-            tuple[float, float, int]: The minimum range (Volts), maximum range (Volts),
+            Tuple[float, float, int]: The minimum range (Volts), maximum range (Volts),
             and number of different discrete channel range settings of the |AnalogIn| instrument.
 
         Raises:
@@ -911,7 +914,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_range = c_channel_range.value
         return channel_range
 
-    def channelRangeSteps(self) -> list[float]:
+    def channelRangeSteps(self) -> List[float]:
         """Report the possible voltage ranges of the |AnalogIn| input channels, in Volts, as a list.
 
         The values returned represent ideal values.
@@ -922,7 +925,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             in a different representation.
 
         Returns:
-            list[float]: A list of ranges, in Volts, representing the discrete
+            List[float]: A list of ranges, in Volts, representing the discrete
             channel range settings of the |AnalogIn| instrument.
 
         Raises:
@@ -937,11 +940,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_range_array = [c_channel_range_array[index] for index in range(channel_range_array_size)]
         return channel_range_array
 
-    def channelOffsetInfo(self) -> tuple[float, float, int]:
+    def channelOffsetInfo(self) -> Tuple[float, float, int]:
         """Get the possible |AnalogIn| input channel offset settings, in Volts.
 
         Returns:
-            tuple[float, float, int]: The minimum channel offset (Volts), maximum channel offset (Volts),
+            Tuple[float, float, int]: The minimum channel offset (Volts), maximum channel offset (Volts),
             and number of steps.
 
         Raises:
@@ -1140,13 +1143,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         channel_impedance = c_channel_impedance.value
         return channel_impedance
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                         INSTRUMENT TRIGGER CONFIGURATION                                         #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                        INSTRUMENT TRIGGER CONFIGURATION                                         #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def triggerSourceInfo(self) -> list[DwfTriggerSource]:
+    def triggerSourceInfo(self) -> List[DwfTriggerSource]:
         """Get the |AnalogIn| instrument trigger source info.
 
         Warning:
@@ -1155,7 +1158,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
             Use the generic |DwfDevice.triggerInfo:link| method instead.
 
         Returns:
-            list[DwfTriggerSource]: A list of trigger sources that can be selected.
+            List[DwfTriggerSource]: A list of trigger sources that can be selected.
 
         Raises:
             DwfLibraryError: An error occurred while retrieving the trigger source information.
@@ -1198,11 +1201,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_source = DwfTriggerSource(c_trigger_source.value)
         return trigger_source
 
-    def triggerPositionInfo(self) -> tuple[float, float, int]:
+    def triggerPositionInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| instrument trigger position range.
 
         Returns:
-            tuple[float, float, int]: The valid range of trigger positions that can be configured.
+            Tuple[float, float, int]: The valid range of trigger positions that can be configured.
             The values returned are the *minimum* and *maximum* valid position settings, and the number of steps.
 
         Raises:
@@ -1287,11 +1290,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_position = c_trigger_position.value
         return trigger_position
 
-    def triggerAutoTimeoutInfo(self) -> tuple[float, float, int]:
+    def triggerAutoTimeoutInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| instrument trigger auto-timeout range, in seconds.
 
         Returns:
-            tuple[float, float, int]: The valid range of trigger auto-timeout values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger auto-timeout values that can be configured.
             The values returned are the *minimum* and *maximum* valid auto-timeout settings, and the number of steps.
 
         Raises:
@@ -1342,18 +1345,18 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger auto-timeout value.
         """
-        c_trigger_autotimeout = typespec_ctypes.c_double()
-        result = self.lib.FDwfAnalogInTriggerAutoTimeoutGet(self.hdwf, c_trigger_autotimeout)
+        c_trigger_auto_timeout = typespec_ctypes.c_double()
+        result = self.lib.FDwfAnalogInTriggerAutoTimeoutGet(self.hdwf, c_trigger_auto_timeout)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_autotimeout = c_trigger_autotimeout.value
-        return trigger_autotimeout
+        trigger_auto_timeout = c_trigger_auto_timeout.value
+        return trigger_auto_timeout
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               FORCE INSTRUMENT TRIGGER                                           #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                            FORCE INSTRUMENT TRIGGER                                             #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def triggerForce(self) -> None:
         """Force assertion of the |AnalogIn| instrument trigger.
@@ -1369,20 +1372,20 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               TRIGGER DETECTOR CONFIGURATION                                     #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                         TRIGGER DETECTOR CONFIGURATION                                          #
+    #                                                                                                                 #
+    ###################################################################################################################
 
-    def triggerHoldOffInfo(self) -> tuple[float, float, int]:
+    def triggerHoldOffInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector holdoff range, in seconds.
 
         The trigger holdoff setting is the minimum time (in seconds) that should pass for a trigger to be
         recognized by the trigger detector after a previous trigger event.
 
         Returns:
-            tuple[float, float, int]: The valid range of trigger detector holdoff values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger detector holdoff values that can be configured.
             The values returned are the *minimum* and *maximum* valid holdoff settings, and the number of steps.
 
         Raises:
@@ -1440,14 +1443,14 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_holdoff = c_trigger_detector_holdoff.value
         return trigger_detector_holdoff
 
-    def triggerTypeInfo(self) -> list[DwfAnalogInTriggerType]:
+    def triggerTypeInfo(self) -> List[DwfAnalogInTriggerType]:
         """Get the valid |AnalogIn| trigger detector trigger-type values.
 
         This setting determines the type of event recognized by the |AnalogIn| trigger detector as a trigger.
         Possible types includes *Edge*, *Pulse*, *Transition*, and *Window*.
 
         Returns:
-            list[DwfAnalogInTriggerType]: A list of trigger detector trigger-types that can be configured.
+            List[DwfAnalogInTriggerType]: A list of trigger detector trigger-types that can be configured.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector trigger-type info.
@@ -1492,7 +1495,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_type = DwfAnalogInTriggerType(c_trigger_detector_type.value)
         return trigger_detector_type
 
-    def triggerChannelInfo(self) -> tuple[int, int]:
+    def triggerChannelInfo(self) -> Tuple[int, int]:
         """Get the |AnalogIn| trigger detector channel range.
 
         The |AnalogIn| trigger detector monitors a specific analog in channel for trigger events.
@@ -1500,7 +1503,7 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         as the |AnalogIn| trigger detector channel.
 
         Returns:
-            tuple[int, int]: The first and last channel that can be used as trigger detector channels.
+            Tuple[int, int]: The first and last channel that can be used as trigger detector channels.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector channel range.
@@ -1550,11 +1553,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_channel_index = c_trigger_detector_channel_index.value
         return trigger_detector_channel_index
 
-    def triggerFilterInfo(self) -> list[DwfAnalogInFilter]:
+    def triggerFilterInfo(self) -> List[DwfAnalogInFilter]:
         """Get a list of valid |AnalogIn| trigger detector filter values.
 
         Returns:
-            list[DwfAnalogInFilter]: A list of filters that can be configured for the trigger detector channel.
+            List[DwfAnalogInFilter]: A list of filters that can be configured for the trigger detector channel.
 
         Raises:
             DwfLibraryError: An error occurred while getting the valid trigger detector channel filter values.
@@ -1599,11 +1602,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_filter = DwfAnalogInFilter(c_trigger_detector_filter.value)
         return trigger_detector_filter
 
-    def triggerLevelInfo(self) -> tuple[float, float, int]:
+    def triggerLevelInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector valid trigger level range, in Volts.
 
         Returns:
-            tuple[float, float, int]: The range of valid trigger levels that can be configured.
+            Tuple[float, float, int]: The range of valid trigger levels that can be configured.
             The values returned are the *minimum* and *maximum* trigger levels in Volts, and the number of steps.
 
         Raises:
@@ -1659,11 +1662,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_level = c_trigger_detector_level.value
         return trigger_detector_level
 
-    def triggerHysteresisInfo(self) -> tuple[float, float, int]:
+    def triggerHysteresisInfo(self) -> Tuple[float, float, int]:
         """Get the |AnalogIn| trigger detector valid hysteresis range, in Volts.
 
         Returns:
-            tuple[float, float, int]: The valid range of trigger hysteresis values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger hysteresis values that can be configured.
             The values returned are the *minimum* and *maximum* trigger hysteresis levels in Volts,
             and the number of steps.
 
@@ -1689,7 +1692,8 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_hysteresis_max = c_trigger_detector_hysteresis_max.value
         trigger_detector_hysteresis_num_steps = int(c_trigger_detector_hysteresis_num_steps.value)
 
-        return (trigger_detector_hysteresis_min, trigger_detector_hysteresis_max, trigger_detector_hysteresis_num_steps)
+        return (trigger_detector_hysteresis_min, trigger_detector_hysteresis_max,
+                trigger_detector_hysteresis_num_steps)
 
     def triggerHysteresisSet(self, trigger_detector_hysteresis: float) -> None:
         """Set the |AnalogIn| trigger detector hysteresis, in Volts.
@@ -1720,11 +1724,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_hysteresis = c_trigger_detector_hysteresis.value
         return trigger_detector_hysteresis
 
-    def triggerConditionInfo(self) -> list[DwfTriggerSlope]:
+    def triggerConditionInfo(self) -> List[DwfTriggerSlope]:
         """Get the valid |AnalogIn| trigger detector condition (slope) options.
 
         Returns:
-            list[DwfTriggerSlope]: A list of valid trigger detector condition (slope) values.
+            List[DwfTriggerSlope]: A list of valid trigger detector condition (slope) values.
 
         Raises:
             DwfLibraryError: An error occurred while getting the valid trigger detector condition values.
@@ -1771,11 +1775,11 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_detector_condition = DwfTriggerSlope(c_trigger_detector_condition.value)
         return trigger_detector_condition
 
-    def triggerLengthInfo(self) -> tuple[float, float, int]:
+    def triggerLengthInfo(self) -> Tuple[float, float, int]:
         """Get the valid |AnalogIn| trigger detector length range, in seconds.
 
         Returns:
-            tuple[float, float, int]: The valid range of trigger detector length values that can be configured.
+            Tuple[float, float, int]: The valid range of trigger detector length values that can be configured.
             The values returned are the *minimum* and *maximum* trigger detector length values in seconds,
             and the number of steps.
 
@@ -1832,13 +1836,13 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         trigger_length = c_trigger_length.value
         return trigger_length
 
-    def triggerLengthConditionInfo(self) -> list[DwfAnalogInTriggerLengthCondition]:
+    def triggerLengthConditionInfo(self) -> List[DwfAnalogInTriggerLengthCondition]:
         """Get a list of valid |AnalogIn| trigger detector length condition values.
 
         Trigger length condition values include *Less*, *Timeout*, and *More*.
 
         Returns:
-            list[DwfAnalogInTriggerLengthCondition]: A list of valid trigger detector length condition values.
+            List[DwfAnalogInTriggerLengthCondition]: A list of valid trigger detector length condition values.
 
         Raises:
             DwfLibraryError: An error occurred while getting the trigger length condition info.
@@ -1876,20 +1880,20 @@ class AnalogIn(AbstractDwfDeviceSubApi):
         Raises:
             DwfLibraryError: An error occurred while getting the trigger detector length condition.
         """
-        c_trigger_detector_length_condition = typespec_ctypes.DwfAnalogInTriggerLengthCondition()
+        c_trigger_length_condition = typespec_ctypes.DwfAnalogInTriggerLengthCondition()
         result = self.lib.FDwfAnalogInTriggerLengthConditionGet(
             self.hdwf,
-            c_trigger_detector_length_condition)
+            c_trigger_length_condition)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        trigger_detector_length_condition = DwfAnalogInTriggerLengthCondition(c_trigger_detector_length_condition.value)
-        return trigger_detector_length_condition
+        trigger_length_condition = DwfAnalogInTriggerLengthCondition(c_trigger_length_condition.value)
+        return trigger_length_condition
 
-    ####################################################################################################################
-    #                                                                                                                  #
-    #                                               SAMPLING CLOCK CONFIGURATION                                       #
-    #                                                                                                                  #
-    ####################################################################################################################
+    ###################################################################################################################
+    #                                                                                                                 #
+    #                                          SAMPLING CLOCK CONFIGURATION                                           #
+    #                                                                                                                 #
+    ###################################################################################################################
 
     def samplingSourceSet(self, sampling_source: DwfTriggerSource) -> None:
         """Set the |AnalogIn| sampling source.
