@@ -63,7 +63,7 @@ class DeviceControl(AbstractDwfLibrarySubApi):
         hdwf = c_hdwf.value
         return DwfDevice(self.dwf, hdwf)
 
-    def openEx(self, options: str, separator: str=",") -> DwfDevice:
+    def openEx(self, options: str, separator: str = ",") -> DwfDevice:
         """Open a device using options given as a string.
 
         This provides an extended (hence the 'Ex' prefix) version of the `:py:meth:open` method.
@@ -103,8 +103,8 @@ class DeviceControl(AbstractDwfLibrarySubApi):
             This method was added in DWF version 3.17.
 
         Parameters:
-            options(str): A string listing options, seperated by a 'separator' string (see below).
-            separator(str): Saperator string, separating options. Default: a single comma (',').
+            options(str): A string listing options, separated by a 'separator' string (see below).
+            separator(str): The separator string that separating options. Default: a single comma (',').
 
         Returns:
             DwfDevice: The |DwfDevice| instance created as a result of this call.
