@@ -1,7 +1,7 @@
 """The |pydwf.core.api.device_enumeration| module implements a single class: |Enum|."""
 
+from typing import Optional, Union, Tuple
 import ctypes
-from typing import Optional, Union
 
 from pydwf.core.dwf_library_subapi import AbstractDwfLibrarySubApi
 
@@ -144,7 +144,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def deviceType(self, device_index: int) -> tuple[int, int]:
+    def deviceType(self, device_index: int) -> Tuple[int, int]:
         """Return the device ID and version (hardware revision) of the selected Digilent Waveforms device.
 
         Note:
@@ -158,7 +158,7 @@ class DeviceEnumeration(AbstractDwfLibrarySubApi):
                 (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer
+            Tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer
             values of the selected Digilent Waveforms device.
 
         Raises:
