@@ -1,5 +1,7 @@
 """The |pydwf.core.api.DigitalI2c| module implements a single class: |DigitalI2c|."""
 
+from typing import List, Tuple
+
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -134,16 +136,16 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def writeRead(self, address: int, tx: list[int], number_of_rx_bytes: int) -> tuple[int, list[int]]:
+    def writeRead(self, address: int, tx: List[int], number_of_rx_bytes: int) -> Tuple[int, List[int]]:
         """Perform a combined I²C write/read operation.
 
         Parameters:
             address (int): The I²C address of the target device.
-            tx (list[int]): The octets to send.
+            tx (List[int]): The octets to send.
             number_of_rx_bytes (int): The number of octets to receive.
 
         Returns:
-            tuple[int, list[int]]:
+            Tuple[int, List[int]]:
                 The first element is the NAK indication; the second element is a list of octet values received.
 
         Raises:
@@ -178,7 +180,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
 
         return (nak, rx_list)
 
-    def read(self, address: int, number_of_words: int) -> tuple[int, list[int]]:
+    def read(self, address: int, number_of_words: int) -> Tuple[int, List[int]]:
         """Perform an I²C read operation.
 
         Parameters:
@@ -209,7 +211,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
 
         return (nak, rx_list)
 
-    def write(self, address: int, tx: list[int]) -> int:
+    def write(self, address: int, tx: List[int]) -> int:
         """Perform an I²C write operation.
 
         Parameters:
@@ -274,11 +276,11 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def spyStatus(self, max_data_size: int) -> tuple[int, int, list[int], int]:
+    def spyStatus(self, max_data_size: int) -> Tuple[int, int, List[int], int]:
         """Get I²C spy status.
 
         Returns:
-            tuple[int, int, list[int], int]: A tuple (start, stop, data-values, nak-indicator).
+            Tuple[int, int, List[int], int]: A tuple (start, stop, data-values, nak-indicator).
 
         Raises:
             DwfLibraryError: An error occurred while executing the operation.
