@@ -1,4 +1,5 @@
 """The |pydwf.core.api.digital_spi| module implements a single class: |DigitalSpi|."""
+from typing import List
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
 
@@ -171,7 +172,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def writeRead(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> list[int]:
+    def writeRead(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
         """Write and read multiple SPI data-words, with up to 8 bits per data-word.
 
         Parameters:
@@ -182,11 +183,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…8).
-            tx (list[int]):
+            tx (List[int]):
                 The data-words to write.
 
         Returns:
-            list[int]: The data-words received.
+            List[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the write/read operation.
@@ -215,7 +216,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def writeRead16(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> list[int]:
+    def writeRead16(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
         """Write and read multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
@@ -230,7 +231,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The data-words to write.
 
         Returns:
-            list[int]: The data-words received.
+            List[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the write/read operation.
@@ -259,7 +260,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def writeRead32(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> list[int]:
+    def writeRead32(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> List[int]:
         """Write and read multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -270,11 +271,11 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…32).
-            tx (list[int]):
+            tx (List[int]):
                 The data-words to write.
 
         Returns:
-            list[int]: The data-words received.
+            List[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the write/read operation.
@@ -304,7 +305,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def read(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> list[int]:
+    def read(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
         """Read multiple SPI data-words, with up to 8 bits per data-word.
 
         Parameters:
@@ -319,7 +320,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The number of data-words to read.
 
         Returns:
-            list[int]: The data-words received.
+            List[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the read operation.
@@ -342,7 +343,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def read16(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> list[int]:
+    def read16(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
         """Read multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
@@ -357,7 +358,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The number of data-words to read.
 
         Returns:
-            list[int]: The data-words received.
+            List[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the read operation.
@@ -380,7 +381,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
 
         return rx_list
 
-    def read32(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> list[int]:
+    def read32(self, transfer_type: int, bits_per_word: int, number_of_words: int) -> List[int]:
         """Read multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -395,7 +396,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 The number of data-words to read.
 
         Returns:
-            list[int]: The data-words received.
+            List[int]: The data-words received.
 
         Raises:
             DwfLibraryError: An error occurred while executing the read operation.
@@ -443,7 +444,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         rx = c_rx.value
         return rx
 
-    def write(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> None:
+    def write(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
         """Write multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -454,7 +455,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…32).
-            tx (list[int]):
+            tx (List[int]):
                 The data-words to write.
 
         Raises:
@@ -477,7 +478,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def write16(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> None:
+    def write16(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
         """Write multiple SPI data-words, with up to 16 bits per data-word.
 
         Parameters:
@@ -488,7 +489,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…16).
-            tx (list[int]):
+            tx (List[int]):
                 The data-words to write.
 
         Raises:
@@ -511,7 +512,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def write32(self, transfer_type: int, bits_per_word: int, tx: list[int]) -> None:
+    def write32(self, transfer_type: int, bits_per_word: int, tx: List[int]) -> None:
         """Write multiple SPI data-words, with up to 32 bits per data-word.
 
         Parameters:
@@ -522,7 +523,7 @@ class DigitalSpi(AbstractDwfDeviceSubApi):
                 * 4 — quad
             bits_per_word (int):
                 The number of bits per data-word (1…32).
-            tx (list[int]):
+            tx (List[int]):
                 The data-words to write.
 
         Raises:
