@@ -1,5 +1,6 @@
 """The |pydwf.core.api.digital_uart| module implements a single class: |DigitalUart|."""
 
+from typing import Tuple
 import ctypes
 
 from pydwf.core.dwf_device_subapi import AbstractDwfDeviceSubApi
@@ -157,7 +158,7 @@ class DigitalUart(AbstractDwfDeviceSubApi):
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def rx(self, rx_max: int) -> tuple[bytes, int]:
+    def rx(self, rx_max: int) -> Tuple[bytes, int]:
         """Receive UART data or prepare for reception.
 
         Important:
@@ -169,7 +170,7 @@ class DigitalUart(AbstractDwfDeviceSubApi):
                 Otherwise, receive the specified number of characters.
 
         Returns:
-            tuple[bytes, int]: Bytes received and parity error indication.
+            Tuple[bytes, int]: Bytes received and parity error indication.
 
         Todo:
             The meaning of the parity error indication is currently unclear.
