@@ -1,6 +1,8 @@
 """The |pydwf.core.dwf_device| module implements a single class: |DwfWaveformsDevice|."""
 
-from typing import List, TYPE_CHECKING
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from pydwf.core.auxiliary.enum_types import DwfTriggerSource, DwfTriggerSlope, DwfDeviceParameter
 from pydwf.core.auxiliary.typespec_ctypes import typespec_ctypes
@@ -19,9 +21,9 @@ from pydwf.core.api.digital_i2c import DigitalI2c
 from pydwf.core.api.analog_impedance import AnalogImpedance
 
 if TYPE_CHECKING:
-    # The DwfLibrary types is needed while type-checking (mypy).
-    from pydwf.core.dwf_library import DwfLibrary
+    # These are only needed when type-checking.
     import ctypes
+    from pydwf.core.dwf_library import DwfLibrary
 
 
 class DwfDevice:
@@ -70,7 +72,7 @@ class DwfDevice:
 
     # pylint: disable=too-many-instance-attributes
 
-    def __init__(self, dwf: 'DwfLibrary', hdwf: int) -> None:
+    def __init__(self, dwf: DwfLibrary, hdwf: int) -> None:
         """Initialize a DwfDevice with the specified DWF handle value.
 
         This method is used by the |DwfLibrary.device.open| method to initialize a |DwfDevice| immediately after
@@ -132,7 +134,7 @@ class DwfDevice:
         return self._hdwf
 
     @property
-    def lib(self) -> 'ctypes.CDLL':
+    def lib(self) -> ctypes.CDLL:
         """Return the |ctypes| shared library instance used to access the DWF library.
 
         This property is intended for internal |pydwf| use.
@@ -156,7 +158,7 @@ class DwfDevice:
             raise self.dwf.exception()
 
     def autoConfigureSet(self, auto_configure: int) -> None:
-        """Enable or disable the auto-configuration setting of the device.
+        """Enable or disable the autoconfiguration setting of the device.
 
         When this setting is enabled (the default), any change to an instrument setting is automatically
         transmitted to the Digilent Waveforms hardware device, without the need for an explicit call to
@@ -165,13 +167,13 @@ class DwfDevice:
         This adds a small amount of latency to every *Set()* method; just as much latency as calling the
         corresponding *configure()* method explicitly after the *Set()* method would add.
 
-        Auto-configuration is enabled by default, and there is little reason to turn it off unless the
+        Autoconfiguration is enabled by default, and there is little reason to turn it off unless the
         user program wants to make frequent changes to many settings at once between measurements.
 
         With value 3, configuration will be applied dynamically, without stopping the instrument.
 
         Parameters:
-            auto_configure (int): Specify auto-configuration setting.
+            auto_configure (int): The new autoconfiguration setting.
 
                 Possible values for this option:
 
@@ -187,10 +189,10 @@ class DwfDevice:
             raise self.dwf.exception()
 
     def autoConfigureGet(self) -> int:
-        """Return the auto-configuration setting of the device.
+        """Return the autoconfiguration setting of the device.
 
         Returns:
-            int: The current auto-configure setting.
+            int: The current autoconfiguration setting.
 
             Possible values for this option:
 
@@ -212,7 +214,7 @@ class DwfDevice:
     def reset(self) -> None:
         """Reset all device and instrument settings to default values.
 
-        The new settings are applied immediately if auto-configuration is enabled.
+        The new settings are applied immediately if autoconfiguration is enabled.
 
         Raises:
             DwfLibraryError: The device cannot be reset.
@@ -234,7 +236,7 @@ class DwfDevice:
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerInfo(self) -> List[DwfTriggerSource]:
+    def triggerInfo(self) -> list[DwfTriggerSource]:
         """Return the available trigger source options for the global trigger bus.
 
         Refer to the section on |triggering:link| for more information.
@@ -248,7 +250,7 @@ class DwfDevice:
         instruments.
 
         Returns:
-            List[DwfTriggerSource]: A list of available trigger sources.
+            list[DwfTriggerSource]: A list of available trigger sources.
 
         Raises:
             DwfLibraryError: The list of supported trigger sources cannot be retrieved.
@@ -322,11 +324,11 @@ class DwfDevice:
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def triggerSlopeInfo(self) -> List[DwfTriggerSlope]:
+    def triggerSlopeInfo(self) -> list[DwfTriggerSlope]:
         """Return the supported trigger slope options.
 
         Returns:
-            List[DwfTriggerSlope]: A list of supported trigger slope values.
+            list[DwfTriggerSlope]: A list of supported trigger slope values.
 
         Raises:
             DwfLibraryError: The trigger slope options cannot be retrieved.
