@@ -1,5 +1,7 @@
 """The |pydwf.core.dwf_library_subapi| module implements a single class: |AbstractDwfLibrarySubApi|."""
 
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -9,7 +11,7 @@ if TYPE_CHECKING:
 class AbstractDwfLibrarySubApi:
     """Abstract base class for the sub-API attributes of a |DwfLibrary|."""
 
-    def __init__(self, dwf: 'DwfLibrary'):
+    def __init__(self, dwf: DwfLibrary):
         self._dwf = dwf
 
     @property
